
/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero cis2794.dta               */
/**********************************************/
/*     Códigos para generar el da2794dta      */
/**********************************************/
version 14
capture confirm file "..\Data\cis2794.dta"
if _rc!=0{
*Este programa necesita que el fichero da2794.dta se encuentre en el directorio
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\cis2794.dta"
*************************************************************
* Generación de una variable de ponderación por sexo y edad *
*************************************************************
* Asignación de variables sexo y edad
global sexo="P32"
global edad="P33"
* Recodificación de la edad
egen INTERedad=cut($edad), at(18, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70, 75, 80, 85, 99)
* Recuento de frecuencias
count if INTERedad==18 & $sexo ==1
scalar e181=r(N)
count if INTERedad==20 & $sexo ==1
scalar e201=r(N)
count if INTERedad==25 & $sexo ==1
scalar e251=r(N)
count if INTERedad==30 & $sexo ==1
scalar e301=r(N)
count if INTERedad==35 & $sexo ==1
scalar e351=r(N)
count if INTERedad==40 & $sexo ==1
scalar e401=r(N)
count if INTERedad==45 & $sexo ==1
scalar e451=r(N)
count if INTERedad==50 & $sexo ==1
scalar e501=r(N)
count if INTERedad==55 & $sexo ==1
scalar e551=r(N)
count if INTERedad==60 & $sexo ==1
scalar e601=r(N)
count if INTERedad==65 & $sexo ==1
scalar e651=r(N)
count if INTERedad==70 & $sexo ==1
scalar e701=r(N)
count if INTERedad==75 & $sexo ==1
scalar e751=r(N)
count if INTERedad==80 & $sexo ==1
scalar e801=r(N)
count if INTERedad==85 & $sexo ==1
scalar e851=r(N)
count if INTERedad==18 & $sexo ==2
scalar e182=r(N)
count if INTERedad==20 & $sexo ==2
scalar e202=r(N)
count if INTERedad==25 & $sexo ==2
scalar e252=r(N)
count if INTERedad==30 & $sexo ==2
scalar e302=r(N)
count if INTERedad==35 & $sexo ==2
scalar e352=r(N)
count if INTERedad==40 & $sexo ==2
scalar e402=r(N)
count if INTERedad==45 & $sexo ==2
scalar e452=r(N)
count if INTERedad==50 & $sexo ==2
scalar e502=r(N)
count if INTERedad==55 & $sexo ==2
scalar e552=r(N)
count if INTERedad==60 & $sexo ==2
scalar e602=r(N)
count if INTERedad==65 & $sexo ==2
scalar e652=r(N)
count if INTERedad==70 & $sexo ==2
scalar e702=r(N)
count if INTERedad==75 & $sexo ==2
scalar e752=r(N)
count if INTERedad==80 & $sexo ==2
scalar e802=r(N)
count if INTERedad==85 & $sexo ==2
scalar e852=r(N)
* Asignación de pesos. España Enero 2009. Fuente INE.
g peso=0
* Hombres
replace peso=30.9217339280042/e181 if INTERedad==18 & $sexo ==1
replace peso=91.3227099598211/e201 if INTERedad==20 & $sexo ==1
replace peso=118.806772511196/e251 if INTERedad==25 & $sexo ==1
replace peso=139.674077640333/e301 if INTERedad==30 & $sexo ==1
replace peso=132.42239800818/e351 if INTERedad==35 & $sexo ==1
replace peso=124.495546920197/e401 if INTERedad==40 & $sexo ==1
replace peso=111.159672971096/e451 if INTERedad==45 & $sexo ==1
replace peso=95.1679917508283/e501 if INTERedad==50 & $sexo ==1
replace peso=81.980577080987/e551 if INTERedad==55 & $sexo ==1
replace peso=75.9282735403541/e601 if INTERedad==60 & $sexo ==1
replace peso=59.7311668557142/e651 if INTERedad==65 & $sexo ==1
replace peso=54.7798023530945/e701 if INTERedad==70 & $sexo ==1
replace peso=47.9259215779285/e751 if INTERedad==75 & $sexo ==1
replace peso=30.4803810148151/e801 if INTERedad==80 & $sexo ==1
replace peso=19.8898142575075/e851 if INTERedad==85 & $sexo ==1
* Mujeres
replace peso=29.1412513116017/e182 if INTERedad==18 & $sexo ==2
replace peso=87.4749206279342/e202 if INTERedad==20 & $sexo ==2
replace peso=112.262862366308/e252 if INTERedad==25 & $sexo ==2
replace peso=129.19454993685/e302 if INTERedad==30 & $sexo ==2
replace peso=123.50191777265/e352 if INTERedad==35 & $sexo ==2
replace peso=119.457832997029/e402 if INTERedad==40 & $sexo ==2
replace peso=109.433070335646/e452 if INTERedad==45 & $sexo ==2
replace peso=96.0157977518352/e502 if INTERedad==50 & $sexo ==2
replace peso=84.3696848760283/e552 if INTERedad==55 & $sexo ==2
replace peso=80.9927345662387/e602 if INTERedad==60 & $sexo ==2
replace peso=65.9348872879268/e652 if INTERedad==65 & $sexo ==2
replace peso=65.7478504566718/e702 if INTERedad==70 & $sexo ==2
replace peso=63.8077210709305/e752 if INTERedad==75 & $sexo ==2
replace peso=48.2762057500418/e802 if INTERedad==80 & $sexo ==2
replace peso=43.7018725222519/e852 if INTERedad==85 & $sexo ==2
* Borrado de INTERedad
drop INTERedad
***************************************************************
/*keep CCAA PROV P0 P501-P503 P601-P603 ///
     P9 P10 P1101-P1302 P32 P34-P41 P4201-P4216 /// Nominales
     TAMUNI P1-P4 P7 P8 P1401-P1407 P20B P22B /// Ordinales
	 P2801 P2802 P2803 P33 peso // Intervalo*/
recode P1-P4 P7 P8 P1401-P1407 (8=.x) (9=.y)
recode P20B P22B(0=.z)(8=.x)(9=.y)
recode  P35A P40 (0=.z)
recode P2801 P2802 (99=.y)
recode P4201-P4216 (.=0) if P4216==.
recode P4201-P4215 (.=.y)
label define P42 0 "No", add
for any P1_P3 P2_P4 P7 P8 P1401_P1407 P20b P22b_P22d ///
        P2801 P33 P42: ///
label define X .x "No sabe" .y "No contesta" .z "No pertinente", add
label value P2801-P2803 P2801
save "..\Data\cis2794.dta", replace
