
/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2009                         */
/**********************************************/
/* Necesita fichero da2798.dta                */
/**********************************************/
/*     Códigos para generar el cis2798dta     */
/**********************************************/
version 11
capture confirm file "..\Data\da2798.dta"
if _rc!=0{
*Este programa necesita que el fichero da2798.dta se encuentre en el directorio
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\da2798.dta"
*************************************************************
* Generación de una variable de ponderación por sexo y edad *
*************************************************************
* Asignación de variables sexo y edad
global sexo="p29"
global edad="p30"
* Recodificación de la edad
egen INTERedad=cut($edad), at(18, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70, 75, 80, 85, 99)
* Recuento de frecuencias
count if INTERedad==18 & $sexo ==1
scalar e181=r(N)
count if INTERedad==20 & $sexo ==1
scalar e201=r(N)
count if INTERedad==25 & $sexo ==1
scalar e251=r(N)
count if INTERedad==30 & $sexo ==1
scalar e301=r(N)
count if INTERedad==35 & $sexo ==1
scalar e351=r(N)
count if INTERedad==40 & $sexo ==1
scalar e401=r(N)
count if INTERedad==45 & $sexo ==1
scalar e451=r(N)
count if INTERedad==50 & $sexo ==1
scalar e501=r(N)
count if INTERedad==55 & $sexo ==1
scalar e551=r(N)
count if INTERedad==60 & $sexo ==1
scalar e601=r(N)
count if INTERedad==65 & $sexo ==1
scalar e651=r(N)
count if INTERedad==70 & $sexo ==1
scalar e701=r(N)
count if INTERedad==75 & $sexo ==1
scalar e751=r(N)
count if INTERedad==80 & $sexo ==1
scalar e801=r(N)
count if INTERedad==85 & $sexo ==1
scalar e851=r(N)
count if INTERedad==18 & $sexo ==2
scalar e182=r(N)
count if INTERedad==20 & $sexo ==2
scalar e202=r(N)
count if INTERedad==25 & $sexo ==2
scalar e252=r(N)
count if INTERedad==30 & $sexo ==2
scalar e302=r(N)
count if INTERedad==35 & $sexo ==2
scalar e352=r(N)
count if INTERedad==40 & $sexo ==2
scalar e402=r(N)
count if INTERedad==45 & $sexo ==2
scalar e452=r(N)
count if INTERedad==50 & $sexo ==2
scalar e502=r(N)
count if INTERedad==55 & $sexo ==2
scalar e552=r(N)
count if INTERedad==60 & $sexo ==2
scalar e602=r(N)
count if INTERedad==65 & $sexo ==2
scalar e652=r(N)
count if INTERedad==70 & $sexo ==2
scalar e702=r(N)
count if INTERedad==75 & $sexo ==2
scalar e752=r(N)
count if INTERedad==80 & $sexo ==2
scalar e802=r(N)
count if INTERedad==85 & $sexo ==2
scalar e852=r(N)
* Asignación de pesos. España Enero 2009. Fuente INE.
capture confirm var peso
if !_rc {
  replace peso=0
}
else {
  generate peso=0
}
* Hombres
replace peso=30.9217339280042/e181 if INTERedad==18 & $sexo ==1
replace peso=91.3227099598211/e201 if INTERedad==20 & $sexo ==1
replace peso=118.806772511196/e251 if INTERedad==25 & $sexo ==1
replace peso=139.674077640333/e301 if INTERedad==30 & $sexo ==1
replace peso=132.42239800818/e351 if INTERedad==35 & $sexo ==1
replace peso=124.495546920197/e401 if INTERedad==40 & $sexo ==1
replace peso=111.159672971096/e451 if INTERedad==45 & $sexo ==1
replace peso=95.1679917508283/e501 if INTERedad==50 & $sexo ==1
replace peso=81.980577080987/e551 if INTERedad==55 & $sexo ==1
replace peso=75.9282735403541/e601 if INTERedad==60 & $sexo ==1
replace peso=59.7311668557142/e651 if INTERedad==65 & $sexo ==1
replace peso=54.7798023530945/e701 if INTERedad==70 & $sexo ==1
replace peso=47.9259215779285/e751 if INTERedad==75 & $sexo ==1
replace peso=30.4803810148151/e801 if INTERedad==80 & $sexo ==1
replace peso=19.8898142575075/e851 if INTERedad==85 & $sexo ==1
* Mujeres
replace peso=29.1412513116017/e182 if INTERedad==18 & $sexo ==2
replace peso=87.4749206279342/e202 if INTERedad==20 & $sexo ==2
replace peso=112.262862366308/e252 if INTERedad==25 & $sexo ==2
replace peso=129.19454993685/e302 if INTERedad==30 & $sexo ==2
replace peso=123.50191777265/e352 if INTERedad==35 & $sexo ==2
replace peso=119.457832997029/e402 if INTERedad==40 & $sexo ==2
replace peso=109.433070335646/e452 if INTERedad==45 & $sexo ==2
replace peso=96.0157977518352/e502 if INTERedad==50 & $sexo ==2
replace peso=84.3696848760283/e552 if INTERedad==55 & $sexo ==2
replace peso=80.9927345662387/e602 if INTERedad==60 & $sexo ==2
replace peso=65.9348872879268/e652 if INTERedad==65 & $sexo ==2
replace peso=65.7478504566718/e702 if INTERedad==70 & $sexo ==2
replace peso=63.8077210709305/e752 if INTERedad==75 & $sexo ==2
replace peso=48.2762057500418/e802 if INTERedad==80 & $sexo ==2
replace peso=43.7018725222519/e852 if INTERedad==85 & $sexo ==2
* Borrado de INTERedad
drop INTERedad
***************************************************************
/*keep CCAA PROV P0 p701-p903 p1601 p1602 ///
     P9 P10 P1101-P1302 p23 p23a p28-p29 p31b-p32 p33-p42 /// Nominales
     TAMUNI p1-p6 p10 p1201-p1203 p1301-p1304
	 p1401-p1510 p18-p19 p21-p22 p24-p2704 p32a p43 p44/// Ordinales
	 p1101-p1107 p1701-p1710 p2001-p2017 p30 peso // Intervalo*/
recode p1-p6 p10 p1201-p1203 p1301-p1304 p1401-p1510 ///
       p18-p19 p21-p22 p43 p44(8=.x) (9=.y)
recode p13a-p13c(99=.y)(98=.x)(0=.z)
recode p13d01-p13d06(0=-1)(.=0)(9=1)
recode p23a p28a (0=.z)(98=.x)(99=.y)
recode p1701-p1710 p2001-p2017 p23(97=.w)(98=.x)(99=.y)
recode p1101-p1107 p24-p2704(98=.x)(99=.y)
label define P42 0 "No", add
for any p1_p4 p2_p6 p701_p803 p10 p1201_p1203 p1301_p1304  ///
        p13a p13b p13c p1401_p1409 P1501_p1510 p1601_p1602 ///
        p18_p19 p21_p22 p23a p24_p26 p2701_p2704 p28a p32a p43 p44 ///
        p1101_p1107 p1701_p1710_p2001_p2017: ///
label define X .w "No conoce".x "No sabe" .y "No contesta" .z "No pertinente", add modify
label define p13d 1 "Sí" 0 "No" -1 "Ninguna", modify
label value p13d01-p13d05 p13d
label define p23 .w "No votaría", modify
label define p28 .x "No recuerda", modify
label define p28a .x "No recuerda", modify
label define p43 .y "No consta", modify
label define p44 .y "No consta", modify
save "..\Data\cis2798.dta", replace
