/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/*      Necesita fichero cis2798.dta          */
/**********************************************/
/*            Ejercicio 7.4                   */
/**********************************************/
version 14
capture confirm file "..\Data\cis2798.dta"
if _rc!=0{
display "Este programa necesita que el fichero cis2798.dta se encuentre en el subdirectorio Data"
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* Se usa el fichero cis2798.dta
use "..\Data\cis2798.dta", clear
* Se procede en primer lugar a realizar la hipótesis por sexo.
* Primero, se realiza la comparación de varianzas
sdtest p1701, by(p29)
* Como sale no significativa, se aplica la comparación de medias sencilla
ttest p1701, by(p29)
* A continuación procede la recodificación de las variables edad e ideología para convertirlas en dicotómicas
recode p30 (min/44=1 "<45") (45/max=2 ">=45"), into(edad2)
recode p24 (1/5=1 "Izquierda") (6/10=2 "Derecha") (else=.), into(ideologia2)
* Tras ello, pueden solicitarse las comparaciones de varianzas
sdtest p1701, by(edad2)
sdtest p1701, by (ideologia2)
* Como con ambas variables se aprecian diferencias significativas, 
ttest p1701, by(edad2) unequal
ttest p1701, by (ideologia2)unequal
* Se sigue el ejercicio recodificando la edad y la ideología en tres categorías:
recode p30 (min/30=1 "Joven") (31/65=2 "Adulto") (66/max=3 "Mayor"), into(edad3)
*Antes de aplicar la prueba, se comprueban los prerrequisitos
bysort edad3:swilk p1701 if edad3
robvar p1701, by(edad3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1701, by(edad3)
* Después de realizarlo con la edad, se procede del mismo modo con la ideología
recode p24 (1/4=1 "Izquierda")(5/6=2 "Centro")(7/10=3 "Derecha")(else=.), into(ideologia3)
bysort ideologia3:swilk p1701
robvar p1701, by(ideologia3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1701, by(ideologia3)
* Todo lo realizado con la variable p1701 puede aplicarse también a p1702 (Mariano Rajoy), p1703 (Cayo Lara) y P1706 (Rosa Díaz) al mismo tiempo:

* Rajoy
bysort edad3:swilk p1702 if edad3
robvar p1702, by(edad3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1702, by(edad3)
* Después de realizarlo con la edad, se procede del mismo modo con la ideología
bysort ideologia3:swilk p1702
robvar p1702, by(ideologia3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1702, by(ideologia3)

* Cayo Lara
bysort edad3:swilk p1703 if edad3
robvar p1703, by(edad3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1703, by(edad3)
* Después de realizarlo con la edad, se procede del mismo modo con la ideología
bysort ideologia3:swilk p1703
robvar p1703, by(ideologia3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1703, by(ideologia3)

*Rosa Díez
bysort edad3:swilk p1706 if edad3
robvar p1706, by(edad3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1706, by(edad3)
* Después de realizarlo con la edad, se procede del mismo modo con la ideología
bysort ideologia3:swilk p1706
robvar p1706, by(ideologia3)
* Tanto la prueba de normalidad como la de homocedasticidad desaconsejan el empleo del análisis de varianza.
* Por ello, se aplica la prueba de Kruskall-Wallis
kwallis p1706, by(ideologia3)
