/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/*      Necesita fichero mundo2005.dta        */
/**********************************************/
/*            Ejercicio 10.1                   */
/**********************************************/
version 14
capture confirm file "..\Data\mundo2005.dta"
if _rc!=0{
*Este programa necesita que el fichero mundo2005.dta se encuentre en el subdirectorio Data"
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* En primer lugar, se cargan los datos:
use "..\Data\mundo2005.dta", clear
* Para crear modelos distintos modelos se realizan las transformaciones con la variable independiente cuantitativa.
capture confirm var ln_rnpcppp
if _rc{
generate ln_rnpcppp=ln(rnpcppp)
}
* Modelo lin-log con continente como variable ficticia:
regress evn ln_rnpcppp ib3.conti
predict evnr, residual
predict evnrs, rstandard
predict evnrt, rstudent
summarize evn?*
rvfplot, mlabel(pais) name(E10_1a, replace) 
sktest evnr-evnrt
swilk evnr-evnrt
sfrancia evnr-evnrt
kdensity evnrt, name(E10_1b, replace)
* Las diferentes pruebas de normalidad de los residuos advierten de problemas
hettest
vif
ovtest
avplot ln_rnpcppp, mlabel(pais) name(E10_1c, replace)
* Análisis de casos individuales
*Residuos
generate evnra=abs(evnr)
gsort -evnra
list pais evnr evnrs evnrt if (abs(evnrs)>1.96 | abs(evnrt)>1.96) & e(sample)
/* Se aprecia cómo los países con residuos más altos corresponden a África,
tanto del norte(Marruecos, Egipto, Algeria), con residuos positivos
como del sur (Sudáfrica, Zimbaue, Botsuana, ...) con residuos negativos*/
*Cargas
predict carga, leverage
gsort -carga
list pais ln_rnpcppp carga in 1/10
lvr2plot, mlabel(pais) name(E10_1d, replace)
dfbeta
list pais _dfb* if (_dfbeta_1>2/sqrt(e(N)) | _dfbeta_2>2/sqrt(e(n)) | _dfbeta_3>2/sqrt(e(n)) | _dfbeta_4>2/sqrt(e(n))) & e(sample)

*Gráficos
*Muestra cómo es África el continente donde falla el modelo
predict evnpp if e(sample)
scatter evnpp rnpcppp, sort(ln_rnpcppp)|| ///
scatter evn rnpcppp if conti==3, mcolor(red)|| ///
scatter evn rnpcppp if conti!=3, mcolor(green)||, name(e10_1e, replace)
*Muestra los paises con problemas en África
generate etiqueta=pais if conti==3 & (rnpcppp>4500 | mod(_n,10)==5) 
scatter evnpp rnpcppp  if rnpcppp<15000 & conti==1, sort(ln_rnpcppp)connect(l) msymbol(i) legend(lab (1 "Ajuste europeo"))|| ///
scatter evnpp rnpcppp  if rnpcppp<15000 & conti==3, sort(ln_rnpcppp)connect(l) msymbol(i) legend(lab (2 "Ajuste africano"))|| ///
scatter evn rnpcppp if conti==3, mcolor(red) mlabel(etiqueta)

/*Como ajusta tan mal, se va a construir un modelo que excluye África y 
tres países mal ajustados en la ecuación anterior: Haití, Laos y Camboya */

use "..\Data\mundo2005.dta", clear
capture confirm var ln_rnpcppp
if _rc{
generate ln_rnpcppp=ln(rnpcppp)
}
*Para crear modelos distintos modelos se realizan las transformaciones con la variable independiente cuantitativa.
*Modelo con países seleccionados de lin-log con continente como variable ficticia
regress evn ln_rnpcppp i.conti if conti!=3 & iso!="HTI" & iso!="KHM" & iso!="LAO"
/*En este caso el R2 pasa de  0,79 a 0,76; pero la predicción yerra menos pues
el error cuadrático medio pasa de 5.90 a 2.6 y los indicadores de la regresión
son mucho más adecuados, como se ve a continución */
predict evnr if e(sample), residual
predict evnrs if e(sample), rstandard
predict evnrt if e(sample), rstudent
summarize evn?*
rvfplot, mlabel(pais) name(E10_1a, replace) 
sktest evnr-evnrt
swilk evnr-evnrt
sfrancia evnr-evnrt
kdensity evnrt, name(E10_1b, replace)
* Las diferentes pruebas de normalidad de los residuos carecen ahora de problemas
hettest
* Tampoco existen problemas de heterocedasticidad
vif
ovtest
avplot ln_rnpcppp, mlabel(pais) name(E10_1c, replace)
* Análisis de casos individuales
*Residuos
generate evnra=abs(evnr)
gsort -evnra
list pais evnr evnrs evnrt if (abs(evnrs)>1.96 | abs(evnrt)>1.96) & e(sample)
/* Existen diez países con residuos con valor absoluto por encima de 1.96
pero no generan problemas de normalidad en la distribución*/
*Cargas
predict carga, leverage
gsort -carga
list pais ln_rnpcppp carga in 1/10
lvr2plot, mlabel(pais) name(E10_1d, replace)
dfbeta
list pais _dfb* if (_dfbeta_1>2/sqrt(e(N)) | _dfbeta_2>2/sqrt(e(n)) | _dfbeta_3>2/sqrt(e(n)) | _dfbeta_4>2/sqrt(e(n))) & e(sample)
/* Sólo la Federación Rusa tiene valores de dfbeta por encima de los deseables
Esto se explica por ser un pais intercontinental. Las más altas corresponden a 
la variable continente */




