/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero cis2794.dta               */
/**********************************************/
/*            Ejercicio 11.1                   */
/**********************************************/
version 14
capture confirm file "..\Data\cis2794.dta"
if _rc!=0{
display "Este programa necesita que el fichero da2794.dta se encuentre en el subdirectorio Data"
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\cis2794.dta"

* Primero, recodificamos las variables que vamos a usar en el análisis.
* Para la variable dependiente, recodificamos para que el tenga valor de 1
* cuando haya usado internet y cero cuando no, y marcamos la no respuesta
* como valor perdido:
recode P27 (2 = 0) (9 = .)

* Recodificamos edad en tres intervalos, y marcamos la no respuesta en
* estudios como valor perdido:
egen EDAD = cut(P33), at(18,30,45,65,98)
recode ESTUDIOS (9 = .)

* Podemos ya estimar el modelo logit. Nótese que las categorías de referencia
* para las variables independientes son: varón, estudios medios, entre 30 y 45
* años de edad (se especifican estas categorías de referencia con el modificador
* ibX).
logit P27 ib1.P32 ib30.EDAD ib3.ESTUDIOS

* La capacidad explicativa del modelo es moderadamente alta, como muestra el
* valor de r2 (.44), y tanto el modelo como la mayor parte de los coeficientes
* son altamente significativos. Para interpretar los coeficientes, es mejor
* transformarlos en cocientes de razón, lo que podemos hacer escribiendo logit,
* or tras la estimación anterior:
 
logit, or

/* La variable que parece tener un mayor impacto sobre el uso de internet es el
 nivel de estudios, aunque las tres variables tienen un impacto considerable.
 La razón de uso de internet disminuye en más de un 99% para los que no tienen
 estudios frente a los que tienen estudios medios, y se multiplica por cuatro
 para los que tienen estudios superiores frente a los que tienen estudios medios.
 La razón de uso de internet (frente a no uso) es menos de la mitad para los que
 tienen más de 45 años que para los que tienen entre 30 y 45, mientras que es un
 64% mayor para los que tienen entre 18 y 30 años. El ser mujer disminuye a la
 mitad la razón de uso de internet frente a ser hombre.
 Los resultados de este modelo logístico binario son muy semejantes a los del
 ejercicio 1 del capítulo 8 (obtenidos a través de tablas de contingencia).
 El modelo logístico confirma que las relaciones son significativas, y que
 estudios y edad tienen mayor influencia que sexo en el uso de internet.
 El ejercicio 3 del capítulo 8 sugería la existencia de interacción entre
 sexo y las otras dos variables independientes. */

* Podemos comprobar esa hipótesis con el modelo logístico de manera sencilla,
* simplemente sacando un modelo específico para cada sexo, mediante la
* preinstrucción bysort (quitamos la variable ficticia de sexo del modelo,
* pues ya no hace falta):
bysort P32: logit P27 ib30.EDAD ib3.ESTUDIOS

/* Estos resultados confirman que, como vimos con tablas de contingencia multinivel,
 el impacto del nivel de estudios y la edad sobre la probabilidad de haber usado
 internet en los últimos doce meses es similar entre mujeres y hombres.
 Nótese que Stata ha eliminado de la estimación a las mujeres sin estudios, puesto
 que ninguna de ellas había utilizado internet en los últimos doce meses y por tanto
 esta variable ficticia predecía perfectamente la posibilidad de ocurrencia de la
 variable dependiente. */
