/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero cis2798.dta               */
/**********************************************/
/*            Ejercicio 11.2                  */
/**********************************************/
version 14
capture confirm file "..\Data\cis2798.dta"
if _rc!=0{
display "Este programa necesita que el fichero cis2798.dta se encuentre en el subdirectorio Data"
exit
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\cis2798.dta"

* Primero, creamos las variables dicotómicas psoe y pp a partir de la variable p23. 
* Descartamos a quienes no van a votar a quienes no contestan
generate psoe=(p23==1) if p23<97
generate pp=(p23==2) if p23<97

* Preparamos las variables de exposición a mass media:
recode p13a (1 = 1 "La uno") (3 = 2 "A3") (5 = 3 "Tele5") (2 4 6 = 4 "Otras nac") (7/96 = 5 "Regionales y otras") (0 97/99 = 6 "Ninguna, no respuesta"), gen(tv)
recode p13b (1 = 1 "Ser") (2 = 2 "Cope") (3 = 3 "Onda0") (4 = 4 "Radio1") (5/96 = 5 "Regionales y otras") (0 97/99 = 6 "Ninguna, no respuesta"), gen(radio)
recode p13c (1 = 1 "El Pais") (2 = 2 "El Mundo") (3 4 = 3 "ABC/La Razón") (5/96 = 5 "Regionales y otros") (0 97/99 = 6 "Ninguno, no respuesta"), gen(prensa)

* Preparamos también las variables edad, ideología y religión:
egen edad = cut(p30), at(18,30,45,65,98)
recode p24 (1/4 = 1 "Izquierda") (5 6 = 2 "Centro") (7/10 = 3 "Derecha") (.x .y = 0 "Sin ideología"), gen(ideol)
recode p32a (1 = 1 "No practicante") (2 3 = 2 "Practicante esporádico") (4 5 = 3 "Practicante asiduo") (9 = .), gen(relig)
replace relig = . if p32 == 9
label define relig 0 "No creyente, ateo", add

* Y ya podemos estimar los modelos logit para intención de voto al PSOE y al PP:
logit psoe ib6.tv ib6.radio ib6.prensa ib0.ideol ib0.relig ib30.edad, or
logit pp ib6.tv ib6.radio ib6.prensa ib0.ideol ib0.relig ib30.edad, or

/* Ambos modelos son significativos estadísticamente, pero la capacidad explicativa
 del modelo de intención de voto al PP es mucho mayor (la r2 es de .48 frente a .33
 en el modelo del PSOE). La intención de voto al PP tiene mayor asociación con la
 exposición a mass media, edad, ideología y religión que la intención de voto al PSOE.
 Sobre el perfil de referencia tomado en el modelo (edad media, católico pero no practicante,
 que no tiene medios de comunicación preferidos , ni ideología)quienes más probabilidad de votar tiene al PSOE
 son los de izquierda, los que ven TV1 o Tele5, así como el tener más de 65 años, con
 respecto a las categorías de referencia (los otros coeficientes positivos de este
 modelo no son significativos estadísticamente). Preferir como medios de comunicación
 Antena 3, la Cope, Onda Cero, El Mundo, el ABC o  La Razón están asociadas a menores
 probabilidades de voto al PSOE con respecto  a no tener ninguna preferencia. 
 
 La razón de voto al PP (frente a no voto) se ve mucho más afectada por las variables
 introducidas en el modelo, como decíamos antes. Muchos de los efectos que veíamos
 con respecto al voto al PSOE aparecen aquí también, pero en el sentido opuesto. Por ejemplo,
 los que optan por la COPE u Onda cero son más propensos al voto al PP; así como los
 lectores de El Mundo, ABC o La Razón.  La variable de religiosidad, que no parecía
 tener una relación significativa con  la intención de voto al PSOE, está fuertemente
 relacionada con el voto al PP (éste aumenta con la práctica religiosa). */
