/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero cis2798.dta                */
/**********************************************/
/*            Ejercicio 12.1                  */
/**********************************************/
version 14
capture confirm file "..\Data\cis2798.dta"
if _rc!=0{
display "Este programa necesita que el fichero cis2798.dta se encuentre en el directorio"
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\cis2798.dta"

* Primero, recodificamos la variable dependiente, para invertir el sentido
* de la variable (hacer que aumente conforme la valoración se hace más positiva)
* y para marcar el no sabe/no contesta como valor perdido:
recode p1 (1 = 5) (2 = 4) (4 = 2) (5 = 1) (8 9 = .)

* Preparamos las variables independientes (vamos a incluir la televisión preferida
* para seguir las noticias políticas como tercera variable independiente):
recode p23 (1 = 1 "PSOE") (2 = 2 "PP") (3/97 .w = 3 "Otros") (98 99 = .), gen(intencion)
recode p13a (1 = 1 "La uno") (3 = 2 "A3") (5 = 3 "Tele5") (2 4 6 = 4 "Otras nac") (7/96 = 5 "Regionales y otras") (0 97/.z = 6 "Ninguna, no respuesta"), gen(tv)

* Y ya podemos ejecutar el ologit:
ologit p1 ib4.ESTATUS ib3.intencion ib6.tv, or

/* Hemos pedido directamente a Stata que muestre los cocientes de razón
 (odds ratio) para facilitar la interpretación de los resultados. El
 modelo es estadísticamente significativo, pero su capacidad explicativa
 es muy limitada (el Pseudo r2 es de .046). La salida de Stata muestra,
 además de los coeficientes (cocientes de razón) para cada variable ficticia
 independiente, los puntos de corte estimados para la variable dependiente
 (equivalentes a la constante). Estos puntos de corte están expresados de
 manera logística (no están exponenciados), al contrario que el resto de
 coeficientes. Sólo tienen interés para el cálculo de probabilidades de
 respuesta de cada una de las categorías ordenadas de la variable dependiente,
 por lo que no los interpretaremos.
 Los coeficientes muestran en cuánto se incrementa la probabilidad de dar una
 respuesta más positiva (con respecto a la evaluación de la economía) para cada
 una de las categorías mostradas con respecto a las categorías de referencia.
 Así, pertenecer a la clase alta o a la nueva clase media está asociado a una
 respuesta más positiva con respecto a la situación económica actual que la
 categoría de referencia (obreros cualificados), lo que probablemente refleje
 que las consecuencias de la crisis están socialmente sesgadas. Pertenecer a
 la vieja clase media o a la clase obrera no cualificada no implica diferencias
 en la opinión de la economía con respecto a la categoría de referencia. Con
 respecto a la intención de voto al PSOE (categoría de referencia), todas las
 otras intenciones de voto están asociadas con una opinión mucho más negativa
 con respecto a la economía (especialmente la intención de voto al PP: la
 oportunidad relativa de tener una opinión positiva es un 70% menor para este
 grupo que para los que declaran que votarán al PSOE). La cadena de televisión
 preferida para seguir la política también tiene un cierto efecto sobre la
 valoración de la economía: los que siguen las noticias por Antena 3 o no siguen
 la política por televisión tienen una opinión claramente más negativa que los
 que las siguen por la Primera, y los que siguen las noticias por la Sexta y
 la Cuatro una opinión más positiva. Las diferencias entre las categorías Tele 5,
 Otras Regionales y la Primera no son significativas al 0.05. */
