/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero cis2798.dta                */
/**********************************************/
/*            Ejercicio 12.2                  */
/**********************************************/
version 14
capture confirm file "..\Data\cis2798.dta"
if _rc!=0{
display "Este programa necesita que el fichero cis2794.dta se encuentre en el directorio"
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\cis2798.dta"

* NOTA: Para realizar este ejercicio, es imprescindible el uso de los comandos
* spost, de Scott Long y Freese. Dado que estos comandos no permiten aún el uso de
* factores (i.xx), utilizaremos variables ficticias creadas a mano.

* Primero, recodificamos la variable dependiente en una variable con
* cinco valores, PSOE, PP, Nacionalistas, IU  y otros (incluyendo el
* voto en blanco o el no voto), marcando como valores perdidos a los
* que dicen que no saben aún o a los que no contestan:
recode p23 (1 = 1 "PSOE") (2 = 2 "PP") (3 = 4 "IU/ICV") (4 5 7/10= 3 "NAC")  (6 11/97 .x= 5 "Otros")  (98 99 .y .z= .), gen(intencion)

* Preparamos las variables de exposición a mass media:
recode p13a (1 = 1 "La uno") (3 = 2 "A3") (5 = 3 "Tele5") (2 4 6 = 4 "Otras nac") (7/96= 5 "Regionales y otras") (0 97/.z = 6 "Ninguna, no respuesta"), gen(tv)
tab tv, gen(tv)
recode p13b (1 = 1 "Ser") (2 = 2 "Cope") (3 = 3 "Onda0") (4 = 4 "Radio1") (5/96= 5 "Regionales y otras") (0 97/.z = 6 "Ninguna, no respuesta"), gen(radio)
tab radio, gen(radio)
recode p13c (1 = 1 "El Pais") (2 = 2 "El Mundo") (3 4 = 3 "ABC/La Razón") (5/96= 5 "Regionales y otros") (0 97/.z = 6 "Ninguno, no respuesta"), gen(prensa)
tab prensa, gen(prensa)

* Preparamos también las variables ideología y religión:
recode p24 (1/4 = 1 "Izquierda") (5 6 = 2 "Centro") (7/10 = 3 "Derecha") (.x .y = 9 "Sin ideología"), gen(ideol)
tab ideol, gen(id)
recode p32a (1 = 1 "No practicante") (2 3 = 2 "Practicante esporádico") (4 5 = 3 "Practicante asiduo") (9 = .), gen(relig)
replace relig = . if p32 == 9
label define relig 0 "No creyente, ateo", add
tab relig, gen(rel)

* Renombramos las variables independientes que vamos a incluir en el modelo.
* Utilizaremos como categoría de referencia a un individuo  que prefiere la Primera
* para informarse de política, que no oye la radio ni lee prensa para informarse
* políticamente (o no respondió a las preguntas p13b y p13c), que es de centro en
* lo ideológico y católico no practicante en lo religioso.

ren tv2 A3
ren tv3 Tele5
ren tv4 TVOtrasNac
ren tv5 TVReg
ren tv6 TVNinguna
ren radio1 Ser
ren radio2 Cope
ren radio3 Onda0
ren radio4 Radio1
ren radio5 RadioReg
ren prensa1 ElPais
ren prensa2 ElMundo
ren prensa3 ABCRazon
ren prensa4 PrensaReg
ren id1 Izq
ren id2 Cen
ren id3 Der
ren rel1 Ateo
ren rel3 PractEspor
ren rel4 PractAsid

* Y ya podemos estimar el logit multinomial:
version 10
mlogit intencion A3 Tele5 TVOtrasNac TVReg TVNinguna ///
                 Ser Cope Onda0 Radio1 RadioReg ///
				 ElPais ElMundo ABCRazon PrensaReg ///
				 Izq Cen Der ///
				 Ateo PractEspor PractAsid

* Para interpretar los resultados, podemos utilizar el comando listcoef,
* mostrando los coeficientes en forma de odds ratio para cada grupo de
* variables independientes:

listcoef A3 Tele5 TVOtrasNac TVReg TVNinguna, pvalue(.05) gt
listcoef Ser Cope Onda0 Radio1 RadioReg, pvalue(.05) gt
listcoef ElPais ElMundo ABCRazon PrensaReg, pvalue(.05) gt
listcoef Izq Der Ateo PractEspor PractAsid, pvalue(.05) gt

* [El comando listcoef pertenece al conjunto de programas spost, de
* Scott Long y Freese, que podemos instalar con el comando
* net install spost9_ado.pkg].

* Las tablas son muy largas, por lo que no las pondremos aquí. Otra
* forma de interpretar los resultados, tal vez más sencilla, es utilizando
* el comando mlogplot:

mlogplot A3 Tele5 TVOtrasNac TVReg TVNinguna, std(00000) p(0.1)
more
mlogplot Ser Cope Onda0 Radio1 RadioReg, std(00000) p(0.1)
more
mlogplot ElPais ElMundo ABCRazon PrensaReg, std(0000) p(0.1)
more
mlogplot Izq Der Ateo PractEspor PractAsid, std(00000) p(0.1)

* El problema que tiene la utilización del comando mlogplot en este caso
* es que algunas variables independientes tienen un efecto tan enorme
* (aunque sea no significativo) en los cocientes de razones de intención
* de voto que la escala del gráfico resulta distorsionada y es difícil
* hacer ninguna interpretación. El comando mlogplot es muy poco flexible,
* no permite por ejemplo mostrar sólo las categorías que sean significativamente
* diferentes de la categoría de referencia (a diferencia de listcoef), lo
* que resolvería este problema. Por ello, las tablas producidas por el comando
* listcoef probablemente sean las más adecuadas para la interpretación de este
* modelo de regresión multinomial.
