/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero daecvt01.dta              */
/**********************************************/
/*            Ejercicio 14.2                  */
/**********************************************/
version 14
capture confirm file "..\Data\daecvt01.dta"
if _rc!=0{
display "Este programa necesita que el fichero daecvt01.dta se encuentre en el directorio"
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\daecvt01.dta"

* La escala de la variable de ponderación no es correcta (los
* datos estaban originalmente grabados sin decimales), por lo que
* es necesario dividir esta variable por 1000:
replace pond = pond/1000.

* Podemos ya aplicar la ponderación y las unidades primarias de muestreo,
* sin especificar estrato aún:
svyset [pweight=pond], psu(v294)
* El comando svydes muestra una descripción básica de la muestra tal y como
* la hemos definido anteriormente:
svydes

* El fichero de la ECVT no incluye la variable de tamaño de municipio que se usó
* para la estratificación, pero incluye otra variable con la que la podemos
* reconstruir parcialmente (sólo nos falta diferenciar las capitales de provincia).
* En el texto no utilizamos esta variable, pero en los ejercicios la utilizaremos
* a modo de ejemplo:
recode v268 (1/3 = 1) (4 = 2) (5=3) (6/7 = 4) (8/9 = 5), gen(tamuni)
svyset [pweight=pond], psu(v294) strata(tamuni)
svydes

* La ECVT de 2001 utilizó dos variables de estratificación, la Comunidad Autónoma y
* el tamaño de municipio.
* Para utilizar la CA como variable de estrato, añadimos el modificador siguiente:
svyset [pweight=pond], psu(v294) strata(v4)
svydes

* Realmente, la estratificación viene definida por el cruce de ambas variables. Para
* generar la variable de estratificación correctamente, podemos multiplicar v4 por
* tamuni, y así tendremos una variable que identificará el estrato en ambas dimensiones
* de manera simultánea:

gen estrato = v4*tamuni
svyset [pweight=pond], psu(v294) strata(estrato)
svydes

* Y con esto ya tendríamos la especificación muestral completa. Para calcular los errores
* típicos, Stata necesita que al menos haya dos unidades primarias por cada estrato, lo que
* no es problema en este caso.
