/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero daecvt01.dta              */
/**********************************************/
/*            Ejercicio 14.3                  */
/**********************************************/
version 14
capture confirm file "..\Data\daecvt01.dta"
if _rc!=0{
display "Este programa necesita que el fichero daecvt01.dta se encuentre en el directorio"
}
* Se borra de memoria cualquier fichero anterior
clear
* Abrimos el fichero
use "..\Data\daecvt01.dta"

* Aplicamos la especificación muestral:
replace pond = pond/1000.
recode v268 (1/3 = 1) (4 = 2) (5=3) (6/7 = 4) (8/9 = 5), gen(tamuni)
gen estrato = v4*tamuni
svyset [pweight=pond], psu(v294) strata(estrato)

* Generamos una variable para seleccionar los casos válidos para la
* regresión (han de ser asalariados, y haber respondido en todas las
* preguntas relevantes):

gen val = (v19==1 | v19==2) & v92!=99 & v146!=9 & v309!=9 & v310!=9

* Veamos primero la regresión sin ponderar:

reg v92 v150 ib3.v146 i.v309 i.v310 if val == 1

* Y ahora con la ponderación antes especificada:

svy, subpop(val): reg v92 v150 ib3.v146 i.v309 i.v310

* Claramente, las variables de tiempo de trabajo introducidas en el
* modelo tienen muy poca influencia sobre la satisfacción en el trabajo
* (el ajuste es muy bajo, y los coeficientes no significativos en la
* mayoría de los casos).

* Si comparamos ambas salidas de Stata, podemos comprobar que tanto
* los coeficientes como los errores típicos (y por tanto, los intervalos
* de confianza) han cambiado ligeramente. Los errores típicos son algo
* mayores, dando lugar a intervalos de confianza más amplios y a una
* menor significatividad estadística en los test de hipótesis. Vemos así
* que es necesaria la utilización del diseño muestral en la estimación
* de parámetros a través de muestras complejas: si no, corremos el riesgo
* de aceptar como válida una diferencia que en realidad se debe a errores
* de muestreo.

* Podemos estimar el mismo modelo sin la variable de estrato, que como
* dijimos antes, tiene el problema de que es sólo una aproximación, puesto
* que los datos de la encuesta no incluyen la variable original.

svyset [pweight=pond], psu(v294)
svy, subpop(val): reg v92 v150 ib3.v146 i.v309 i.v310

* Como vemos, los coeficientes son idénticos a los obtenidos con la
* especificación anterior. Lo único que cambia es el error típico de
* los coeficientes, y muy poco (a veces se amplía ligeramente, otras
* se reduce, que es lo más habitual). Por tanto, la adición del estrato
* aproximado a la especificación muestral no tiene muchas ventajas en
* este caso, y podemos obviarla (como se hace en el texto del libro).

 
