/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita mundo                             */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "ficheroa.dta"
if _rc!=0{
display "Ponga por defecto el directorio donde se encuentran los datos con la instrucción cd"
}
clear
set mem 10M

/**********************************************/
/*   La información en los archivos de Stata  */
/**********************************************/
sysuse dir
/**********************************************/
/*         Las ventanas de Stata              */
/**********************************************/
help
dir
sysuse auto

histogram price, freq
edit
doedit


/**********************************************/
/*       Modos de trabajo con Stata           */
/**********************************************/
db histogram
db sysuse
do listauto

/**********************************************/
/*         El fichero de resultados           */
/**********************************************/
log using capitulo02, replace
list make price
log close
view capitulo02.smcl

/**********************************************/
/*     Las variables del fichero de datos     */
/**********************************************/
use data/mundo, clear
describe

/**********************************************/
/*     Etiquetas de variables y valores       */
/**********************************************/
label data "Indicadores de los paises. Mundo(2002)"
label variable pib "Producto interior bruto"
label define conti 1 "Europa" 2 "Asia" 3 "África" 4 "América" 5 "Oceanía", replace
label values continente conti
label define perte 0 "No" 1 "Sí", replace
label values ocde perte
label values ue perte
label values ocde

/**********************************************/
/*   Formatos de presentación de variables    */
/**********************************************/
list pais superficie pib tmi tascrec in 1/10
format %8.0g superficie pib tmi tascrec
list pais superficie pib tmi tascrec in 1/10
format %24s pais
list pais tmi in 1/5, clean 
display %d -365, %d 0, %d 366
display %dd_M_cY  -364, %dM/d/Y 1, %dd-n-CY 367
