/***********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi      */
/*  Análisis de datos con Stata                */
/*  Madrid. CIS. 2020                          */
/***********************************************/
/* Usa: fichero4a fichero4b europa panel4      */
/*      calificaciones "distribucion muestral" */
/***********************************************/
/*               Introducción                  */
/***********************************************/
version 14
capture confirm file "Data\fichero4a.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
log using "capitulo4", replace
clear
set mem 500M
set more off
set scheme sj
/**********************************************/
/*                                            */
/*         Ejercicios del capítulo 4          */
/*                                            */
/**********************************************/
/**********************************************/
/*        Clasificación de variables          */
/**********************************************/
use "Data\fichero4a.dta"
codebook sexo edad

/**********************************************/
/*   La tabla de distribución de frecuencias  */
/**********************************************/
tab1 sexo edad

/**********************************************/
/* Medidas características de la distribución */
/**********************************************/
use "Data\europa.dta", clear
list pais superficie poblacion evn
summarize superficie poblacion evn
summarize poblacion, detail
tabstat poblacion superficie densidad
tabstat poblacion superficie densidad, statistics(mean median sd skewness kurtosis)
tabstat poblacion superficie densidad, statistics(mean median sd skewness kurtosis) column(statistics)
tabstat poblacion superficie densidad, statistics(mean median sd skewness kurtosis) column(statistics) by(fundador)

/**********************************************/
/*       La ponderación de los datos          */
/**********************************************/
use "Data\calificaciones.dta", clear
list, clean
tab1 nota [fweight=frecuencia]
summarize nota [fweight=frecuencia], detail
use "Data\fichero4b.dta", clear
tabulate sexo [aweight=elevacion]
summarize sexo [aweight=elevacion]
tabulate sexo [iweight=elevacion]
summarize sexo [iweight=elevacion]

/**********************************************/
/*            El error típico                 */
/**********************************************/
use "Data\distribucion muestral.dta", clear
tabulate phombres
summarize phombres, detail

/**********************************************/
/*   Estimación e intervalos de confianza     */
/**********************************************/
cii 100 40
cii 100 .4 sqrt(.40*.60)
use "Data\panel4.dta", clear
ci edad
ci hombre mujer, binomial

log close
set more on
