/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita  ejemplo6, panel6, mundo996       */ 
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "Data\ejemplo6.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
log using "capitulo6", replace
clear
set mem 500M
set scheme sj
/**********************************************/
/*                                            */
/* Ejercicios del capítulo 6                  */
/*                                            */
/**********************************************/

/**********************************************/
/*  Características de los gráficos de Stata  */
/**********************************************/
sysuse auto, clear
histogram price
histogram mpg, name(Hist_Mpg, replace)
graph dir
graph describe Graph
graph rename Graph Hist_Price, replace
graph display Hist_Mpg
graph copy Hist_Mpg Mpg, replace
graph drop Hist_Mpg
graph combine Hist_Price Mpg, name(G1,replace)


/**********************************************/
/*  Gráficos unidimensionales                 */
/**********************************************/
use "Data\ejemplo6.dta", clear
graph pie Hombre Mujer, name(G2, replace)
use "Data\panel6.dta", clear
graph pie, over(sexo) name(G3, replace)
graph pie, over(sexo) by(Voto_2000)name(G4, replace)
use "Data\ejemplo6.dta", clear
graph bar Hombre Mujer, nolabel name(G5, replace)
use "Data\panel6.dta", clear
tabulate sexo
generate casos=100/r(N)
graph bar (count) casos, over(sexo)name(G6, replace)
graph bar (count) casos, over(Voto_2000) over(sexo)name(G7, replace)
graph bar (count) casos, over(Voto_2000) by(sexo, total ) name(G8, replace)
graph bar (sum) casos, over(Voto_2000) name(G9, replace)
graph bar (count)casos, over(Voto_2000) asyvar by(sexo) stack name(G10, replace)
graph bar (count) casos, over(Voto_2000) asyvar by(sexo) stack percent name(G11, replace)
graph hbar (sum) casos, over(Voto_2000) asyvar name(G12, replace)
histogram edad, name(G13, replace)
histogram edad, bin(8) name(G14, replace)
histogram edad, start(15) width(10) name(G15, replace)
histogram edad, start(15) width(10) frequency normal name(G16, replace)
graph twoway  (histogram edad) (kdensity edad), name(G17, replace)
graph box edad, name(G18, replace)
tabstat ideopp-ideoiu, statistics(p25 p50 p75)
graph box ideopp-ideoiu, name(G19, replace)
graph box ideopp, over(Voto_2000) name(G20, replace)
graph box ideopp ideopsoe, over(Voto_2000) over(sexo) name(G21, replace)

/**********************************************/
/*  Gráficos bidimensionales                 */
/**********************************************/
use "Data\mundo996.dta", clear
scatter evn pnbppa, name(G22, replace)
scatter tmi pnbppa, name(G23a, replace)
scatter lintfno pnbppa, name(G23b, replace)
scatter evn tmi, name(G23c, replace)
scatter evn pnbppa, name(G23d, replace)
graph combine G23a G23b G23c G23d, name(G23, replace)

graph twoway bar  pob  supkm2, name(G24a, replace) title("Gráfico de barras")
graph twoway dropline  pob  supkm2, name(G24c, replace) title("Gráfico de líneas caídas (dropline)")
graph twoway spike  pob  supkm2, name(G24b, replace) title("Gráficos de clavos (spike)")
graph twoway dot pob supkm2, name(G24d, replace) title("Gráficos de puntos")
graph combine G24a G24b G24c G24d, name(G24, replace)

graph matrix tmi pnbppa evn, half name(G25, replace)

graph twoway connected evn tmi, sort name(G26a, replace)
graph twoway line evn tmi, sort name(G26b, replace)
graph combine G26a G26b, name(G26, replace)

graph twoway area evn tmi, sort name(G27, replace)

graph twoway lfit evn tmi, name(G28, replace)
graph twoway (lfit evn tmi) (scatter evn tmi)
graph twoway lfit evn tmi || scatter evn tmi, name(G29, replace)

twoway (qfit evn pnbppa) (scatter evn pnbppa), name(G30a, replace) title("Ajuste qfit")
twoway (fpfit evn pnbppa) (scatter evn pnbppa), name(G30b, replace) title("Ajuste fpfit")
twoway (lowess evn pnbppa) (scatter evn pnbppa), name(G30c, replace) title("Ajuste lowess")
twoway (mspline evn pnbppa) (scatter evn pnbppa), name(G30d, replace) title("Ajuste mspline")
graph combine G30a G30b G30c G30d, name(G30, replace)

graph  twoway rbar lintfno pcx1000 pnbppa, name(G31a, replace) title("rbar")
graph  twoway rcap lintfno pcx1000 pnbppa, name(G31b, replace) title("rcap")
graph  twoway rarea lintfno pcx1000 pnbppa, sort name(G31c, replace) title("rarea")
graph  twoway rline lintfno pcx1000 pnbppa, sort name(G31d, replace) title("rline")
graph combine G31a G31b G31c G31d, name(G31, replace)

graph twoway (qfitci evn pnbppa) (scatter evn pnbppa), name(G32a, replace)
graph twoway (fpfitci evn pnbppa) (scatter evn pnbppa), name(G32b, replace)
graph combine G32a G32b, name(G32, replace)

graph twoway function y=2+.5*x, name(G33, replace)
graph twoway function y=normalden(x), range(-2.5 2.5) n(9)name(G34, replace)

graph query, schemes
query graphics
use "Data\panel6.dta", clear
set scheme economist
graph box ideopp-ideoiu, title("Partidos", position(12))name(G35, replace)

log close
set more on
