/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                        */
/**********************************************/
/* Necesita fichero panel7.dta                */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
* Añadir un asterisco a la siguiente línea, si ya ha instalado el programa snp2
net install snp2.pkg, replace
capture confirm file "Data\panel7.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
log using "capitulo7", replace
clear
set mem 500M
set more off
set scheme sj
/**********************************************/
/*                                            */
/* Ejercicios del capítulo 7                  */
/*                                            */
/**********************************************/

/**********************************************/
/*      Pruebas de una sola variable          */
/**********************************************/
use "Data\panel7.dta", clear
generate intpp=(intvoto==2) if (intvoto <97 | intvoto==98)
label var intpp "Intención de voto al PP"
tabulate intvoto intpp, missing
prtest intpp==.35
ttest  pvotopp==5, level(99)
tabulate pvotopp
signtest pvotopp=5

/**********************************************/
/*      Comparación de dos variables          */
/**********************************************/
generate intpsoe=(intvoto==3) if (intvoto<97 | intvoto==98)
prtest intpp=intpsoe
ttest pvotopp==pvotopsoe
signtest pvotopp=pvotopsoe
signrank pvotopp=pvotopsoe in 1/10
signrank pvotopp=pvotopsoe

/**********************************************/
/* Comparación de dos muestras independientes */
/**********************************************/
ttest intpp, by(sexo)
sdtest pvotopp, by(sexo)
ttest pvotopp, by (sexo)
ranksum pvotopp, by (sexo)

/**********************************************/
/*  Comparación de k muestras independientes  */
/**********************************************/
recode edad 18/25=1 26/35=2 36/45=3 46/55=4 56/65=5 66/75=6 76/98=7  99=., gen(edadr)
tabulate edadr, summarize(pvotopp)
label define edadint 1 "18-25" 2 "26-35" 3 "36-45" 4 "46-55" 5 "56-65" 6 "66-75" 7 "75+"
label values edadr edadint
tabulate edadr, summarize(pvotopp)
kwallis pvotopp, by(edadr)
replace estudios=1 if (escuela==1 | escuela==2)
recode estudios .=9
label define estudios 1 "Sin estudios", add
bysort estudios: swilk pvotopp
robvar pvotopp, by(estudios)
oneway pvotopp estudios
oneway pvotopp estudios, noanova scheffe

/**********************************************/
/*   Comparación de k muestras dependientes   */
/**********************************************/
use "Data\panel7.dta", clear
generate partido1=ideopp
generate partido2=ideopnv
generate partido3=ideoea
recode partido1-partido3 (98 99=.)
drop if partido1==. | partido2==. | partido3==.
sample 50
keep id partido1-partido3
reshape long partido, i(id) j(par)
label define partidos 1 "PP" 2 "PNV" 3 "EA"
label values par partidos
tabstat partido, by(par) statistics(n mean sd)

use "Data\panel7.dta", clear
mark selecciona
markout selecciona ideopp ideoea ideopnv
friedman ideopp ideoea ideopnv if selecciona
log close
