/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero panel8.dta                */
/**********************************************/
/*               Introducción                 */
/**********************************************/
* Añadir asteríscos a las cuatro siguientes líneas, si ya ha instalado los programas tab_chi y mrtab
net from http://www.stata.com/users/njc
net install tab_chi
ssc install mrtab
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
log using "capitulo8", replace
clear
set mem 500M
set more off
/**********************************************/
/*                                            */
/* Ejercicios del capítulo 8                  */
/*                                            */
/**********************************************/

/**********************************************/
/*   Tablas de contigencia de dos variables   */
/**********************************************/
use "Data\panel8.dta", clear
tab1 rvoto ingresos
tabulate rvoto ingresos
tabulate rvoto ingresos, col
tabulate rvoto ingresos, row nofreq
tabulate rvoto ingresos, cell nofreq
tabulate rvoto ingresos if rvoto != 99 & ingresos != 9, col nofreq
tabulate rvoto ingresos if rvoto != 99 & ingresos != 9, expected
tabchi rvoto ingresos if rvoto!=99 & ingresos !=9 , noo noe raw pearson adjust
tabulate rvoto ingresos if rvoto != 99 & ingresos != 9, nofr chi2 V
tabulate ideologia ingresos if ideol!=99 & ingresos!=9, col all

/**********************************************/
/*            Más de dos variables            */
/**********************************************/
recode edad (18/49=1 "18/49") (50/98=2 "50/98"), into(edadr)
label variable edadr "Edad"
bysort edadr: tabulate rvoto ingresos if rvoto != 99 & ingresos != 9, col nofreq chi2 V
bysort sexo edadr: tabulate rvoto ingresos if rvoto != 99 & ingresos != 9, col nofreq chi2 V

/**********************************************/
/*        Otras tablas especiales             */
/**********************************************/
tabulate edadr, summarize(ideopp)
bysort sexo: tabulate edadr ingresos, summarize(ideopp)
tabstat ideopp ideopsoe ideoiu, s(n mean q iqr sd skewness kurtosis) col(variable)
tabstat ideopp ideopsoe ideoiu, statistics(n mean sd sk k) col(statistics) by (edadr)
recode ccaa 13=1 .=. else=2, into(comunidad)
label define madrid 1 "Madrid" 2 "Resto"
label val comunidad madrid
bysort comunidad: table rvoto ingresos edadr if ingresos <4, by(sexo) cellwidth(8)
table rvoto edadr, content(mean ideopp mean ideopsoe) format(%3.1f) col row

/**********************************************/
/*     Las tablas de respuesta múltiple       */
/**********************************************/
use "Data\panel8.dta",clear 
tab1 p21a01-p21a14
mrtab p21a01-p21a14, title("Recuerdo de publicidad")nonames
replace p21a14=1 if p21==9
generate p21a15=0
replace p21a15=1 if p21==2
label variable p21a15 "No ha visto"
mrtab p21a01-p21a14 p21a15, title("Recuerdo de publicidad")nonames

mrtab p39a01 p39a02, poly response(1/99) title(Opciones en duda) nonames
mrtab p39a01 p39a02, poly response(1/99) title(Opciones en duda) nonames include

mrtab p21a01-p21a14 p21a15, title("Recuerdo de publicidad")nonames by(sexo) col nofreq mtest chi2

log close
set more on
