/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero mundo99.dta               */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "Data\mundo99.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
capture log using "capitulo9", replace
clear all
set mem 20M
set more off
set scheme sj

/**********************************************/
/*   Nube de puntos, varianza y correlación   */
/**********************************************/
use "Data\mundo99.dta", clear
scatter tmi pnbppa, name(G1, replace)
summarize tmi
global tmix=r(mean)
summarize pnbppa
global pnbppax=r(mean)
scatter tmi pnbppa, xline($pnbppax) yline($tmix)name(G2, replace)
correlate tmi pnbppa, covariance
generate valido= tmi<. & pnbppa<.
foreach X of varlist tmi pnbppa{
   egen z`X'=std(`X') if valido
}
scatter ztmi zpnbppa, xline(0) yline(0) xlabel(-1 0/3) ylabel(-1 0/3)name(G3, replace)
correlate ztmi zpnbppa, covariance
correlate tmi pnbppa

/**********************************************/
/*          La regresión simple               */
/**********************************************/
generate tztmi=-.640543*zpnbppa
scatter tztmi ztmi zpnbppa if valido, connect(l i) msymbol(i O) ///
        xline(0) yline(0) sort(zpnbppa) name(G5, replace)
regress ztmi zpnbppa
regress tmi pnbppa
generate ttmib=65.15607 + -.0031526*pnbppa
predict ttmi
scatter ttmi tmi pnbppa if valido, connect(l i) msymbol(i O) ///
        xline($pnbppax) yline($tmix) sort(pnbppa) name(G6, replace)
/**********************************************/
/*    Inferencias en la regresión simple      */
/**********************************************/
test _cons pnbppa
test pnbppa=-0.003
/**********************************************/
/*          La regresión múltiple             */
/**********************************************/
regress tmi pnbppa pibag
regress tmi pnbppa pibag, beta nohead
regress tmi pnbppa pibag lintfno, nohead
regress tmi pnbppa pibag lintfno, nohead beta

/**********************************************/
/*    Regresión con variables ficticias      */
/**********************************************/
generate africa=(conti==3) if conti<.
regress tmi pnbppa africa
predict ptmi0 if ~africa
label var ptmi0 "Ajuste resto"
predict ptmi1 if africa
label var ptmi1 "Ajuste africano"
gen tmia=tmi if africa
label var tmia "Tmi africana"
gen tmir=tmi if ~africa
label var tmir "Tmi resto"
scatter ptmi1 ptmi0 tmia tmir pnbppa if e(sample) & ptmi0>0, ///
        connect (l l . .)lpattern(solid dash) symbol(i i o s) ///
        ytitle("Tasa de mortalidad infantil por mil") ///
        sort(pnbppa)name(G8, replace)

regress tmi pnbppa i.conti
regress tmi pnbppa ib4.conti
predict ptmi
twoway (scatter tmi pnbppa, legend(label(1 "Tasa de mortalidad infantil (1988)"))) ///
       (lfit ptmi pnbppa if conti==1, lpattern (solid) legend(label(2 "África"))) ///
       (lfit ptmi pnbppa if conti==2, legend(label(3 "America"))) ///
       (lfit ptmi pnbppa if conti==3, legend(label(4 "Asia"))) ///
	   (lfit ptmi pnbppa if conti==4, legend(label(5 "Europa"))) ///
       (lfit ptmi pnbppa if conti==5, legend(label(6 "Oceanía"))) ///
	   if (e(sample)& tmi<100 & ptmi>0) ///
	   ,ytitle("Tasa de mortalidad infantil") name(G9, replace) 
test 4.conti=3.conti
test 3.conti=2.conti
contrast gw.conti
/**********************************************/
/*       Regresiones con interacción          */
/**********************************************/
regress tmi c.pnbppa##i.africa
predict ptmi0X if !africa
label var ptmi0X "Ajuste resto"
predict ptmi1X if africa
label var ptmi1X "Ajuste africano"
scatter ptmi1X ptmi0X tmia tmir pnbppa if e(sample) & ptmi0X>0, ///
        connect (l l . .)lpattern(solid dash) symbol(i i o s) ///
        ytitle("Tasa de mortalidad infantil por mil") sort(pnbppa) name(G10, replace)
regress tmi c.pnbppa##c.pibag
regress tmi pnbppa ib4.conti##ocde
regress tmi ib4.conti##c.pnbppa
regress tmi ib4.conti#c.pnbppa

/**********************************************/
/*Predicciones ajustadas y efectos marginales*/
/**********************************************/
quietly: regress tmi c.pnbppa##conti
margins
margins conti
margins conti, at(pnbppa=(2000(4000)10000))
marginsplot,  noci  ///
                     plot1opts(lpattern(dash)) ///
                     plot2opts(lpattern(dot)) ///
                     plot3opts(lpattern(shortdash)) ///
                     plot5opts(lpattern(dash_dot)) ///
                     title("Predicciones ajustas por continente") ///
                     ytitle("Predicción lineal") ///
                     legend(cols(5) size(small)) ///
                     name(G11, replace)
quietly: regress tmi c.pnbppa##ib4.conti
margins, dydx(conti) at(pnbppa=(0))
quietly: margins, dydx(conti) at(pnbppa=(0 5000 7122 10000))
marginsplot,  noci ///
                      plot1opts(lpattern(dash) ) ///
                      plot2opts(lpattern(dot)) ///
                      plot3opts(lpattern(shortdash)) ///
                      plot4opts(lpattern(dash_dot)) ///
                      title("Efectos marginales por continente (base= Europa)") ///
                      ytitle("Efectos sobre la predicción lineal") ///
                      legend(cols(4) size(small) ///
                      order(1 "África" 2 "América" 3 "Asia" 4 "Oceanía")) ///
                      name(G12, replace)

/**********************************************/
/*Otras relaciones funcionales de la regresión*/
/**********************************************/
regress tmi c.pnbppa##c.pnbppa
quietly: margins, at(pnbppa=(0(3000)30000))
marginsplot, noci addplot(scatter tmi pnbppa if pnbppa<=30000, ///
                      title("Modelo cuadrático: predicciones ajustadas") ///
                      ytitle("Tasa de mortalidad infantil") ///
                      xlabel(0(10000)30000) /// 
                      legend(order(1 "Ajuste cuadrático"))) ///
                      name(G13, replace)
					  
regress tmi c.pnbppa## c.pnbppa## c.pnbppa
quietly: margins, at(pnbppa=(0(3000)30000))
marginsplot, noci addplot(scatter tmi pnbppa if pnbppa<=30000, ///
             title("Modelo cúbico: predicciones ajustadas") ///
             ytitle("Tasa de mortalidad infantil") ///
             xlabel(0(10000)30000) ///
             legend(order(1 "Ajuste cúbico"))) ///
             name(G14, replace)	
			 
generate invpnb=1/pnbppa
regress tmi invpnb
			 predict ttminv if e(sample)
label variable ttminv "Predicción inversa"
sort pnbppa
scatter ttminv tmi pnbppa if e(sample), connect (l .)symbol(i o) name(G15, replace)

generate l_pnbppa=ln(pnbppa)
generate l_tmi=ln(tmi)
regress l_tmi l_pnbppa
predict ttmigg if e(sample)
generate ttmgg=exp(ttmigg)
label variable ttmgg "Predicción log-log"
scatter ttmgg tmi pnbppa if e(sample), connect (l .) symbol (i o) name(G16, replace)

* generate l_tmi=ln(tmi) // Previamente generada
regress l_tmi pnbppa
predict ttmign if e(sample)
generate ttmgn=exp(ttmign)
label variable ttmgn "Predicción log-lin"
scatter ttmgn tmi pnbppa if e(sample), connect (l .) symbol (i o) name(G17, replace)

* generate l_pnbppa=ln(pnbppa) // Previamente generada
regress tmi l_pnbppa
predict ttming if e(sample)
label variable ttming "Predicción lin-log"
scatter ttming tmi pnbppa if e(sample), connect (l) symbol (i o) name(G18, replace)

log close
set more on
