/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero mundo99.dta               */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "Data\mundo99.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
capture log using "capitulo10", replace
clear all
set mem 20M
set more off
set scheme sj
/**********************************************/
/*                                            */
/*      Ejemplos del capítulo 10              */
/*                                            */
/**********************************************/

/**********************************************/
/*      Diagnósticos de la regresión          */
/**********************************************/
use "Data\mundo99.dta", clear
regress tmi pnbppa
predict tmir, residual
predict tmirt, rstandard
predict tmirs, rstudent
summarize tmi*
rvfplot, name(G1, replace)
sktest tmi?*
swilk tmir-tmirt
sfrancia tmir-tmirt
kdensity tmirt, normal name(G2, replace)
hettest
regress tmi pnbppa lintfno pibag
vif
graph matrix pnbppa lintfno pibag, half name(G3, replace)
regress tmi pnbppa
ovtest
for var tmi pnbppa: generate l_X=ln(X)
regress l_tmi l_pnbppa
ovtest
regress l_tmi l_pnbppa lintfno
avplot l_pnbppa, mlabel(pais)
avplot lintfno, mlabel(pais)name(G4, replace)

/**********************************************/
/*    Análisis de los casos en la regresión   */
/**********************************************/
use "Data\mundo99.dta", clear
for var tmi pnbppa: generate l_X=ln(X)
regress l_tmi l_pnbppa lintfno
for any r rs rt \ any residual rstandar rstudent: predict ltmiX, Y
generate ltmira=abs(ltmir)
gsort -ltmira
list pais ltmir ltmirs ltmirt if (abs(ltmirs)>1.96 | abs(ltmirt)>1.96) & e(sample)
label var ltmirs "Residuales estandarizados"
label var ltmirt "Residuales studentizados"
graph box ltmirs ltmirt, name(G5, replace)
predict carga, leverage
gsort -carga
list pais l_pnbppa lintfno carga in 1/10
lvr2plot, mlabel(pais) ytitle(Carga) xtitle(Residuos normalizados al cuadrado)name(G6, replace)
regress l_tmi  l_pnbppa lintfno
dfbeta
list pais _dfb* if (_dfbeta_1>2/sqrt(e(N)) | _dfbeta_2>2/sqrt(e(N))) & e(sample)
regress l_tmi l_pnbppa lintfno if pais~="Surafrica"
regress l_tmi l_pnbppa lintfno if _dfbeta_1<2/sqrt(e(N)) & _dfbeta_2<2/sqrt(e(N))
regress l_tmi  l_pnbppa lintfno
for any dfits cooksd welsch: predict l_tmi_X, X
list pais l_tmi_* if (abs(l_tmi_dfits)>2*sqrt((e(df_m)+1)/e(N)) | ///
                            l_tmi_cooksd>4*e(N) | ///
                            abs(l_tmi_welsch)>3*sqrt(e(df_m)+1)) & e(sample)
regress l_tmi l_pnbppa lintfno if ~(abs(l_tmi_dfits)>2*sqrt((e(df_m)+1)/e(N)) | ///
                                                        l_tmi_cooksd>4/e(N) | /// 
                                                       abs(l_tmi_welsch)>3*sqrt(e(df_m)+1))
predict l_tmi_cov, covratio
sort l_tmi_cov
list pais l_tmi_cov if abs(l_tmi_cov-1)>=3*(e(df_m)+1)/e(N) & e(sample)



/**********************************************/
/*          Regresiones especiales            */
/**********************************************/
regress l_tmi l_pnbppa lintfno, robust
generate Europa=(conti==1) if conti<.
regress evn tmi if Europa==1
regress evn tmi [weight=Europa]
clear
input str1 caso byte(X Y peso2 peso3)
A 1 5 1 1
B 2 4 2 1
C 2 6 1 2
end
generate peso=sqrt(peso2)
regress Y X
regress Y X  [weight=peso2], nohead
predict R2
regress Y X  [weight=peso3], nohead
predict R3
regress Y X [aweight=peso2]
regress Y X [fweight=peso2]
regress Y X [aweight=1/peso2]
vwls Y X, sd(peso)

/**********************************************/
/*          Regresión robusta                 */
/**********************************************/
use "Data\mundo99.dta", clear
for var tmi pnbppa: generate l_X=ln(X)
rreg l_tmi l_pnbppa lintfno
rreg l_tmi l_pnbppa lintfno, graph
rreg l_tmi l_pnbppa lintfno, genwt(w_ltmi)
sort w_ltmi
list pais w_ltmi in 1/10

summarize lintfno
local xtfno=r(mean)
regress tmi pnbppa lintfno
matrix coef=e(b)
generate t_tmi=coef[1,3]+coef[1,1]*pnbppa+coef[1,2]*`xtfno'
rreg tmi pnbppa lintfno
matrix rcoef=e(b)
generate rt_tmi=rcoef[1,3]+rcoef[1,1]*pnbppa+rcoef[1,2]*`xtfno'
regress l_tmi l_pnbppa lintfno
matrix coef=e(b)
generate tl_tmix=coef[1,3]+coef[1,1]*l_pnbppa+coef[1,2]*`xtfno'
generate tl_tmiy=exp(tl_tmix)
rreg l_tmi l_pnbppa lintfno
matrix rcoef=e(b)
generate rtl_tmix=rcoef[1,3]+rcoef[1,1]*l_pnbppa+rcoef[1,2]*`xtfno'
generate rtl_tmiy=exp(rtl_tmix)
label variable t_tmi "Tasa predicha lineal"
label variable rt_tmi "Tasa predicha lineal y robusta"
label variable tl_tmiy "Tasa predicha log-log"
label variable rtl_tmiy "Tasa predicha log-log y robusta"
scatter tl_tmiy rtl_tmiy t_tmi rt_tmi pnbppa, connect (. l . l) symbol(o . o .) ///
        l1title("Tasa de mortalidad infantil")sort(pnbppa)name(G10, replace)

/**********************************************/
/*         Regresión de cuantiles             */
/**********************************************/
use "Data\mundo99.dta", clear
generate l_pnbppa=ln(pnbppa)
qreg tmi l_pnbppa
clear
input X Y
0 1
0 2
0 3
1 7
1 8
1 9
end
version 12 // A partir de la versión 13 cambia el método VCE por defecto
qreg Y X
qreg Y X, quantile(.25)

version 14
use "Data\mundo99.dta", clear
reg tmi pnbppa
predict ttmi
label var ttmi "Prediccion minimos cuadrados"
qreg tmi pnbppa
predict qtmi
label var qtmi "Predicción por cuantiles"
scatter qtmi ttmi pnbppa, connect (. l) symbol (o .)sort(pnbppa)name(G11, replace)

graph twoway mband tmi pnbppa, bands(10)name(G12, replace)

log close
set more on
