/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero panel11.dta               */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
* Añadir un asterisco a la siguiente línea, si ya ha instalado los programas spost
* net install spost9_ado.pkg
capture confirm file "Data\panel11.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
capture log using "capitulo11", replace
clear
set mem 50M
set more off
set scheme sj

/**********************************************/
/*                                            */
/*  Ejemplos del capítulo 11                  */
/*                                            */
/**********************************************/
use "Data\panel11"
do capitulo11R /*Llama a un programa para preparar las variables dependientes e independientes*/

/**********************************************/
/*           Estimación del modelo            */
/**********************************************/
logit manif mujer edad i.estudios i.ingresos
test edad
test edad mujer
test 2.ingresos=3.ingresos

/**********************************************/
/*          Diagnóstico del modelo            */
/**********************************************/
predict resmanif, rs
label var resmanif "Residuos estandarizados"
list manif resmanif in 1/10 if resmanif <.
scatter resmanif edad, ylabel(-2 0 2) name(G2, replace)
recode resmanif (. -2.7/2.7=0) (else=1), into(extremo)
sort resmanif
list resmanif manif sexo edad estudios ingresos if extremo, clean noobs

predict cook, dbeta
summarize cook, detail
count if cook >.10 & cook<.
list cook manif sexo edad estudios ingresos if cook >.10 & cook <., clean

fitstat
estat classification
estat ic

/**********************************************/
/*           Comparación de modelos           */
/**********************************************/
quietly logit manif mujer edad i.estudios i.ingresos amadecasa estudiante
quietly fitstat, save
quietly logit manif mujer edad i.estudios i.ingresos amadecasa
fitstat, dif
logit manif mujer edad i.estudios i.ingresos jubilado parado estudiante amadecasa
estimates store Modelo3, title("Modelo superior")
logit manif mujer edad i.estudios i.ingresos jubilado amadecasa if e(sample)
estimates store Modelo2, title("Modelo intermedio")
logit manif mujer edad i.estudios i.ingresos if e(sample)
estimates store Modelo1, title("Modelo inferior")
estimates table Modelo1 Modelo2 Modelo3, star stats(N ll_0 ll chi2 r2_p aic bic)
estimates table Modelo1 Modelo2 Modelo3,  b (%6.1f) se(%6.2f) p(%6.2e)

/**********************************************/
/*       Interpretación del modelo            */
/**********************************************/
logit manif mujer edad i.estudios i.ingresos , or
listcoef
logit manif mujer edad estu2 estu3 ingr2 ingr3
prchange mujer, fromto
prchange edad, fromto
prgen edad, from (18) to (95) generate(edad)ci
label variable edadx "Valores distintos de edad"
label variable edadp1 "Probabilidad de acudir a una manifestación P(y=1|x)"
graph twoway (rarea edadp1lb edadp1ub edadx) /// 
             (connected edadp1 edadx, mcolor(black) msymbol(circle)msize(medium)), ///
             ylabel(0(.1).5) name(G5, replace) ///
             xtitle("Valores distintos de edad") ///
             ytitle("Rango de probabilidad de acudir a manifestación") ///
             legend(label(2 "P(y=1)") order(2))
prgen edad, from(18) to(95) generate(edadhombre) x(mujer=0)ci
prgen edad, from(18) to(95) generate(edadmujer) x(mujer=1)ci
label variable edadhombrep1 "P(y=1|hombres)"
label variable edadmujerp1 "P(y=1|mujeres)"
graph twoway (rarea edadhombrep1lb edadhombrep1ub edadx) ///
             (rarea edadmujerp1lb edadmujerp1ub edadx) ///
             (connected edadhombrep1 edadx, mcolor(black) msymbol(square)) ///
             (connected edadmujerp1 edadx, mcolor(black) msymbol(circle)), ///
             ylabel(0(.1).5) name(G6, replace) ///
             xtitle("Valores distintos de edad") ///
             ytitle("Rango de probabilidad de acudir a manifestación") ///
             legend(label(1 "P(y=1|hombres)") label(2 "P(y=1|mujeres)") ///
             label(3 "") label(4 ""))
prvalue, x(estu3=0 estu2=0 edad=25) rest(mean)
prvalue, x(estu3=1 estu2=0 edad=40) rest(mean)
prvalue, x(estu3=0 estu2=0 edad=51) rest(mean)

log close
