/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 20020                         */
/**********************************************/
/* Necesita fichero unemployment.dat          */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "Data\unemployment.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
capture log using "capitulo13", replace
clear
set mem 50M
set more off
set scheme sj
/**********************************************/
/*                                            */
/*  Ejemplos del capítulo 13                  */
/*                                            */
/**********************************************/

/**********************************************/
/*     Órdenes para definir los datos         */
/**********************************************/
use "Data\unemployment.dta", clear
stset end, origin(begin) fail(dest==1) /*acontecimiento definido como transición a la ocupación*/
list  id org dest begin end  _d _t _t0 in 1/9, nod nol noob clean

stset end, origin(begin) fail(dest==2) /*acontecimiento definido como transición a la inactividad*/
list  id org dest begin end  _d _t _t0 in 1/9, nod nol noob clean

/**********************************************/
/*     La función de supervivencia            */
/**********************************************/

stset end, origin(begin) fail (dest==1) /*función de supervivencia para la salida del desempleo*/
sts graph, ylabel(, angle(horizontal)) xlabel(0 (12) 120) ///
                 xtitle(Duración del episodio de desempleo) ///
                 title(Función de supervivencia, position (0) ring(0)) ///
                 name(G1, replace)
sts graph, ylabel(, angle(horizontal)) xlabel(0 (12) 120) ///
                xtitle(Duración del episodio de desempleo) ///
                title(Funciones de supervivencia) ///
                by(cohort) name(G2, replace)


*******************************************
* Instucciones de los gráficos de la Figura 13.3
* (Estos códigos no aparecen en el libro). 
* Ver Bernardi (2006)
*******************************************				
************************************
*Creación de datos ficticios
************************************
clear
set obs 90
*definir 90 observaciones

generate t=(_n-1)/30
*crea una variable t para las 90 observaciones, _n asume un numero progresivo de 1 a 90

*EXPONENCIAL
generate e1=1
lab var e1 "a=1"
generate e2=0.5
lab var e2 "a=0.5"
generate e3=2
lab var e3 "a=2"
*crea el gráfico
graph twoway line e1 e2 e3 t, yscale(range(0 3)) ylabel(0 (0.5) 3) ytitle(r(t)) title("Exponencial") name(G3A, replace)

*GOMPERTZ
*Gompertz a=1 b=-0.5
generate g1=exp(t*(-0.5))
lab var g1 "a=1 b=-0.5"
*Gompertz a=1 b=0.5
generate g2=exp(t*0.5)
lab var g2 "a=1 b=0.5"
*Gompertz a=1 b=0
generate g3=exp(0)
lab var g3 "a=1 b=0"
*crea el gráfico
graph twoway line g1 g2 g3 t if g2<=3, yscale(range(0 3)) ylabel(0 (0.5) 3) xlabel(0(1)2) ytitle(r(t)) title("Gompertz") name(G3B, replace)

*WEIBULL
*weibull a=1 b=0.5
generate w1=0.5*t^(-0.5)
lab var w1 "a=1 b=0.5"
*weibull a=1 b=1.5
generate w2=1.5*t^0.5
lab var w2 "a=1 b=1.5"
*weibull a=1 b=1
generate w3=1*t^0
lab var w3 "a=1 b=1"
*crea el gráfico
graph twoway line w1 w2 w3 t, yscale(range(0 3)) ylabel(0 (0.5) 3) ytitle(r(t)) title("Weibull") name(G3C, replace)

*LOG-LOGISTIC
*log-logistic a=1 b=3
generate l1= (3*t^2)/(1+(t^3))
lab var l1 "a=1 b=3"
*log-logistic a=1 b=1
generate l2= 1/(1+t)
lab var l2 "a=1 b=1"
*log-logistic a=1 b=0.5
generate l3= (0.5*(t^(-0.5)))/(1+(t^0.5))
lab var l3 "a=1 b=0.5"
*crea el gráfico
graph twoway line l1 l2 l3 t, yscale(range(0 3)) ylabel(0 (0.5) 3) ytitle(r(t)) title("Log-logístico") name(G3D, replace)
*Combinación de los 4 gráficos en uno solo
graph combine G3A G3B G3C G3D, name(G3, replace)
				
				
/**********************************************/
/*     Modelos con tiempo continuo            */
/**********************************************/
use "Data\unemployment.dta", clear
stset end, origin(begin) fail (dest==1) /*acontecimiento definido como transición a la ocupación*/
streg i.sex i.cohort, dist(exp) nohr /*modelo exponencial*/
streg i.sex i.cohort, dist(gomp) nohr /*modelo gompertz*/
stcox i.sex i.cohort,  nohr /*modelo cox*/

log close
