/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Necesita fichero daecvt.dta                */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
capture confirm file "Data\daecvt01.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
capture log using "capitulo14", replace
clear all
set mem 500M
set more off
set scheme sj
/**********************************************/
/*                                            */
/*  Ejemplos del capítulo 14                  */
/*                                            */
/**********************************************/
clear
set mem 10m
use "Data\daecvt01"
des, s

** Preparamos la ponderación con svyset:

replace pond = pond/1000.
svyset [pweight=pond], psu(v294)
* svyset [pweight=pond], psu(v294) strata(v4) /*Diseño alternativo con las CCAA como variable de estrato*/
* svyset [pweight=pond], psu(v294) strata(v293) /*Otro diseño alternativo con el hábitat como variable de estrato*/
svydes

** Sólo queremos estudiar a los asalariados, pero no podemos
** simplemente eliminarlos (con drop, por ejemplo), puesto que
** para la estimación de la varianza, errores, etc, Stata
** necesita información de todas las variables, aunque la estimación
** de las medias sólo se refiera a los casos que nos interesen
** Lo que hacemos es usar la opción subpop para que las estimaciones
** se refieran sólo a los casos que nos interesen: para ello, primero
** creamos una variable (asal) que tiene 1 si el caso es asalariado y
** 0 si no.

gen asal = 1 if v19==1 | v19==2
replace asal = 0 if v19!=1 & v19!=2

** Esta es la variable general para trabajar con el subsample que nos
** interesa: ahora creamos otra para analizar la satisfacción laboral,
** que como tiene mucho ns/nc que no nos interesa meter en el análisis,
** y no se puede hacer un if por lo dicho en el comentario anterior,
** tenemos que usar una variable de selección que llamamos valsat

gen valsat = 1 if asal==1 & v92!=99
replace valsat = 0 if asal==0 | v92==99

** Proporciones: gente que busca otro empleo:

tab v42 if asal == 1
svy, subpop(asal): prop v42

** Medias: satisfacción con el trabajo:

ci v92 if valsat == 1
svy, subpop(valsat): mean v92
estat effects

** Medias por grupos: satisfacción y búsqueda de otro empleo

bysort v42: ci v92 if valsat == 1
svy, subpop(valsat):mean v92, over(v42)

** Tabla trabajo nocturno por búsqueda de otro empleo:

tab v42 v146 if asal == 1, col all
svy, subpop(asal): tab v42 v146, obs col per se ci


** Variable de selección en la que eliminamos (==0) todos los
** casos con ns/nc en la regresión múltiple siguiente:

gen valtime = 1 if valsat==1 & v146!=9 & v309!=9 & v310!=9
replace valtime = 0 if valsat!=1 | v146==9 | v309==9 | v310==9

** Regresión: satisfacción por variables de tiempo de trabajo:

reg v92 v150 i.v146 i.v309 i.v310 if valtime == 1
**(lo del i. es para convertir en dummies las variables no continuas, para
** poder hacer una regresión, ver help fvvarlist para más información)
svy, subpop(valtime):reg v92 v150 i.v146 i.v309 i.v310

** Logit: búsqueda de otro empleo en función del tiempo de trabajo

** Como la variable dependiente en el logit debe ser 0-1 (no ocurrencia-ocurrencia
** del suceso estudiado), cambiamos los valores de la variable v42 para que nos
** sirva:
gen busq = 2 - v42
**(y esto para crear una variable de selección para la estimación)
gen valbusq = 1 if asal==1 & v146!=9 & v309!=9 & v301!=9
replace valbusq = 0 if asal!=1 | v146==9 | v309==9 | v310==9
logit busq v150 i.v146 i.v309 i.v310 if valbusq == 1
svy, subpop(valbusq):logit busq v150 i.v146 i.v309 i.v310

log close
