/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2009                         */
/**********************************************/
/*     Necesita fichero daecvt01.dta          */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 8
capture confirm file "Data\daecvt01.dta"
if _rc!=0{
display "Ponga por defecto el directorio donde se encuentran los datos con la instrucción cd"
exit
}
capture log using "capitulo14b", replace
clear
set mem 500M
set more off
set scheme sj
/**********************************************/
/*                                            */
/*  Ejemplos del capítulo 14 con versión 8    */
/*                                            */
/**********************************************/
version 8
set more off


** Apéndice sobre los comandos svy
** utilizando la ECVT 2001

** Abrimos la base de datos

clear
set mem 10m
use "Data\daecvt01.dta"
des, s

** Preparamos la ponderación con svyset:

replace pond = pond/1000.
svyset [pweight=pond], psu(v294)

** Sólo queremos estudiar a los asalariados, pero no podemos
** simplemente eliminarlos (con drop, por ejemplo), puesto que
** para la estimación de la varianza, errores, etc, Stata
** necesita información de todas las variables, aunque la estimación
** de las medias sólo se refiera a los casos que nos interesen
** Lo que hacemos es usar la opción subpop para que las estimaciones
** se refieran sólo a los casos que nos interesen: para ello, primero
** creamos una variable (asal) que tiene 1 si el caso es asalariado y
** 0 si no.

gen asal = 1 if v19==1 | v19==2
replace asal = 0 if v19!=1 & v19!=2

** Esta es la variable general para trabajar con el subsample que nos
** interesa: ahora creamos otra para analizar la satisfacción laboral,
** que como tiene mucho ns/nc que no nos interesa meter en el análisis,
** y no se puede hacer un if por lo dicho en el comentario anterior,
** tenemos que usar una variable de selección que llamamos valsat

gen valsat = 1 if asal==1 & v92!=99
replace valsat = 0 if asal==0 | v92==99

** Proporciones: gente que busca otro empleo:

tab v42 if asal == 1
svyprop v42, subpop(asal)

** Medias: satisfacción con el trabajo:

ci v92 if valsat == 1
svymean v92, subpop(valsat)

** Medias por grupos: satisfacción y búsqueda de otro empleo

bysort v42: ci v92 if valsat == 1
svymean v92, by(v42) subpop(valsat)

** Tabla trabajo nocturno por búsqueda de otro empleo:

tab v42 v146 if asal == 1, col all
svytab v42 v146, obs col per subpop(asal)

** Variable de selección en la que eliminamos (==0) todos los
** casos con ns/nc en la regresión múltiple siguiente:

gen valtime = 1 if valsat==1 & v146!=9 & v309!=9 & v301!=9
replace valtime = 0 if valsat!=1 | v146==9 | v309==9 | v310==9

** Regresión: satisfacción por variables de tiempo de trabajo:

xi:reg v92 v150 i.v146 i.v309 i.v310 if valtime == 1
**(lo del xi es para convertir en dummies las variables no continuas, para
** poder hacer una regresión, ver help xi para más información)
xi: svyreg v92 v150 i.v146 i.v309 i.v310, subpop(valtime)

** Logit: búsqueda de otro empleo en función del tiempo de trabajo

** Como la variable dependiente en el logit debe ser 0-1 (no ocurrencia-ocurrencia
** del suceso estudiado), cambiamos los valores de la variable v42 para que nos
** sirva:
gen busq = 2 - v42
**(y esto para crear una variable de selección para la estimación)
gen valbusq = 1 if asal==1 & v146!=9 & v309!=9 & v301!=9
replace valbusq = 0 if asal!=1 | v146==9 | v309==9 | v310==9
xi:logit busq v150 i.v146 i.v309 i.v310 if valbusq == 1
xi:svylogit busq v150 i.v146 i.v309 i.v310, subpop(valbusq)

log close
set more on
